@@ -19,6 +19,7 @@ class Egg(models.Model):
     name = models.CharField(_('name'), unique=True, blank=False, max_length=50)
     package = models.CharField(_('package name'), unique=True, blank=False, max_length=50)
     url = models.CharField(_('url'), blank=True, max_length=255)
+    summary = models.TextField(_('summary'), blank=True)
     description = models.TextField(_('description'), blank=True)
 
     def __unicode__(self):
@@ -76,6 +77,9 @@ class WebsiteEnvironment(models.Model):
     def __unicode__(self):
         return "{website} {env}".format(website=self.website.name, env=self.name)
     
+    def get_used_eggs(self):
+        return self.eggs.all().select_related().order_by('egg__name')
+    
     class Meta:
         verbose_name = _("website environment")
         verbose_name_plural = _("websites environments")
